Module: FFI::NCurses
- Extended by:
- Library, NCurses, BoolWrappers, EmulatedFunctions
- Includes:
- ACS, Attributes, BoolWrappers, Color, Constants, Darwin, EmulatedFunctions, KeyDefs, Mouse, PanelStruct, WinStruct
- Included in:
- NCurses
- Defined in:
- lib/ffi-ncurses.rb,
lib/ffi-ncurses/acs.rb,
lib/ffi-ncurses/mouse.rb,
lib/ffi-ncurses/panel.rb,
lib/ffi-ncurses/darwin.rb,
lib/ffi-ncurses/keydefs.rb,
lib/ffi-ncurses/ncurses.rb,
lib/ffi-ncurses/version.rb,
lib/ffi-ncurses/typedefs.rb,
lib/ffi-ncurses/functions.rb,
lib/ffi-ncurses/winstruct.rb,
lib/ffi-ncurses/bool_wrappers.rb
Defined Under Namespace
Modules: ACS, Attributes, BoolWrappers, Color, Compatibility, Constants, Darwin, EmulatedFunctions, KeyDefs, Mouse, PanelStruct, WinStruct
Constant Summary collapse
- FUNCTION_SIGNATURES =
FFI overwrites the signatures when you call =attach_function= so I keep an untouched deep copy here (used in the Ncurses compatibility layer).
Marshal.load(Marshal.dump(FUNCTIONS))
- LIB_HANDLE =
Use
RUBY_FFI_NCURSES_LIBto specify a colon-separated list of libs you want to try to load, e.g.RUBY_FFI_NCURSES_LIB=XCurses:ncursesto try to load XCurses (from PDCurses) first, then ncurses.
{ }
- WACS_BLOCK =
Wide character versions. These are Unicode definitions so don't need to be defined dynamically.
From http://invisible-island.net/ncurses/man/curs_add_wch.3x.html
Name Unicode Default Description
0x25ae- WACS_BOARD =
solid square block
0x2592- WACS_BTEE =
board of squares
0x2534- WACS_BULLET =
-
bottom tee
-
0x00b7- WACS_CKBOARD =
o bullet
0x2592- WACS_DARROW =
: checker board (stipple)
0x2193- WACS_DEGREE =
v arrow pointing down
0x00b0- WACS_DIAMOND =
' degree symbol
0x25c6- WACS_GEQUAL =
-
diamond
-
0x2265- WACS_HLINE =
greater-than-or-equal-to 0x2500- WACS_LANTERN =
-
horizontal line
-
0x2603- WACS_LARROW =
lantern symbol
0x2190- WACS_LEQUAL =
< arrow pointing left
0x2264- WACS_LLCORNER =
< less-than-or-equal-to
0x2514- WACS_LRCORNER =
-
lower left-hand corner
-
0x2518- WACS_LTEE =
-
lower right-hand corner
-
0x2524- WACS_NEQUAL =
-
left tee
-
0x2260- WACS_PI =
! not-equal
0x03c0- WACS_PLMINUS =
-
greek pi
-
0x00b1- WACS_PLUS =
plus/minus
0x253c- WACS_RARROW =
-
plus
-
0x2192- WACS_RTEE =
arrow pointing right 0x251c- WACS_S1 =
-
right tee
-
0x23ba- WACS_S3 =
-
scan line 1
-
0x23bb- WACS_S7 =
-
scan line 3
-
0x23bc- WACS_S9 =
-
scan line 7
-
0x23bd- WACS_STERLING =
_ scan line 9
0x00a3- WACS_TTEE =
f pound-sterling symbol
0x252c- WACS_UARROW =
-
top tee
-
0x2191- WACS_ULCORNER =
^ arrow pointing up
0x250c- WACS_URCORNER =
-
upper left-hand corner
-
0x2510- WACS_VLINE =
-
upper right-hand corner
-
0x2502- WACS_T_ULCORNER =
Name Unicode Default Description
0x250f- WACS_T_LLCORNER =
-
thick upper left corner
-
0x2517- WACS_T_URCORNER =
-
thick lower left corner
-
0x2513- WACS_T_LRCORNER =
-
thick upper right corner
-
0x251b- WACS_T_LTEE =
-
thick lower right corner
-
0x252b- WACS_T_RTEE =
-
thick tee pointing right
-
0x2523- WACS_T_BTEE =
-
thick tee pointing left
-
0x253b- WACS_T_TTEE =
-
thick tee pointing up
-
0x2533- WACS_T_HLINE =
-
thick tee pointing down
-
0x2501- WACS_T_VLINE =
-
thick horizontal line
-
0x2503- WACS_T_PLUS =
| thick vertical line
0x254b- WACS_D_ULCORNER =
-
thick large plus or crossover
-
0x2554- WACS_D_LLCORNER =
-
double upper left corner
-
0x255a- WACS_D_URCORNER =
-
double lower left corner
-
0x2557- WACS_D_LRCORNER =
-
double upper right corner
-
0x255d- WACS_D_RTEE =
-
double lower right corner
-
0x2563- WACS_D_LTEE =
-
double tee pointing left
-
0x2560- WACS_D_BTEE =
-
double tee pointing right
-
0x2569- WACS_D_TTEE =
-
double tee pointing up
-
0x2566- WACS_D_HLINE =
-
double tee pointing down
-
0x2550- WACS_D_VLINE =
-
double horizontal line
-
0x2551- WACS_D_PLUS =
| double vertical line
0x256c- NAME =
"ffi-ncurses"- VERSION =
"0.4.0"- FUNCTIONS =
this list of function signatures was generated by the file gentypes.rb
[ [:COLOR_PAIR, [:int], :int], [:PAIR_NUMBER, [:int], :int], [:_nc_tracebits, [], :string], [:_traceattr, [:attr_t], :string], [:_traceattr2, [:int, :chtype], :string], [:_tracecchar_t, [:cchar_t_p], :string], [:_tracecchar_t2, [:int, :cchar_t_p], :string], [:_tracechar, [:int], :string], [:_tracechtype, [:chtype], :string], [:_tracechtype2, [:int, :chtype], :string], [:_tracedump, [:string, :window_p], :void], [:_tracef, [:string, :varargs], :void], [:_tracemouse, [:mevent_p], :string], [:_wrapped_clearok, :clearok, [:window_p, :bool], :int], [:_wrapped_idcok, :idcok, [:window_p, :bool], :void], [:_wrapped_idlok, :idlok, [:window_p, :bool], :int], [:_wrapped_immedok, :immedok, [:window_p, :bool], :void], [:_wrapped_initscr, :initscr, [], :window_p], [:_wrapped_intrflush, :intrflush, [:window_p, :bool], :int], [:_wrapped_keyok, :keyok, [:int, :bool], :int], [:_wrapped_keypad, :keypad, [:window_p, :bool], :int], [:_wrapped_leaveok, :leaveok, [:window_p, :bool], :int], [:_wrapped_meta, :meta, [:window_p, :bool], :int], [:_wrapped_mouse_trafo, :mouse_trafo, [:int_p, :int_p, :bool], :bool], [:_wrapped_newterm, :newterm, [:string, :file_p, :file_p], :screen_p], [:_wrapped_nodelay, :nodelay, [:window_p, :bool], :int], [:_wrapped_notimeout, :notimeout, [:window_p, :bool], :int], [:_wrapped_scrollok, :scrollok, [:window_p, :bool], :int], [:_wrapped_syncok, :syncok, [:window_p, :bool], :int], [:_wrapped_use_env, :use_env, [:bool], :void], [:_wrapped_use_extended_names, :use_extended_names, [:bool], :int], [:_wrapped_wmouse_trafo, :wmouse_trafo, [:window_p, :int_p, :int_p, :bool], :bool], [:add_wch, [:cchar_t_p], :int], [:add_wchnstr, [:cchar_t_p, :int], :int], [:add_wchstr, [:cchar_t_p], :int], [:addch, [:chtype], :int], [:addchnstr, [:chtype_p, :int], :int], [:addchstr, [:chtype_p], :int], [:addnstr, [:string, :int], :int], [:addnwstr, [:wchar_t_p, :int], :int], [:addstr, [:string], :int], [:addwstr, [:wchar_t_p], :int], [:assume_default_colors, [:int, :int], :int], [:attr_get, [:attr_t_p, :short_p, :pointer], :int], [:attr_off, [:attr_t, :pointer], :int], [:attr_on, [:attr_t, :pointer], :int], [:attr_set, [:attr_t, :short, :pointer], :int], [:attroff, [:attr_t], :int], [:attron, [:attr_t], :int], [:attrset, [:attr_t], :int], [:baudrate, [], :int], [:beep, [], :int], [:bkgd, [:chtype], :int], [:bkgdset, [:chtype], :void], [:bkgrnd, [:cchar_t_p], :int], [:bkgrndset, [:cchar_t_p], :void], [:border, [:chtype, :chtype, :chtype, :chtype, :chtype, :chtype, :chtype, :chtype], :int], [:border_set, [:cchar_t_p, :cchar_t_p, :cchar_t_p, :cchar_t_p, :cchar_t_p, :cchar_t_p, :cchar_t_p, :cchar_t_p], :int], [:bottom_panel, [:panel_p], :int], [:box, [:window_p, :chtype, :chtype], :int], [:box_set, [:window_p, :cchar_t_p, :cchar_t_p], :int], [:can_change_color, [], :bool], [:cbreak, [], :int], [:chgat, [:int, :attr_t, :short, :pointer], :int], [:clear, [], :int], [:clrtobot, [], :int], [:clrtoeol, [], :int], [:color_content, [:short, :short_p, :short_p, :short_p], :int], [:color_set, [:short, :pointer], :int], [:copywin, [:window_p, :window_p, :int, :int, :int, :int, :int, :int, :int], :int], [:curs_set, [:int], :int], [:curses_version, [], :string], [:def_prog_mode, [], :int], [:def_shell_mode, [], :int], [:define_key, [:string, :int], :int], [:del_panel, [:panel_p], :int], [:delay_output, [:int], :int], [:delch, [], :int], [:deleteln, [], :int], [:delscreen, [:screen_p], :void], [:delwin, [:window_p], :int], [:derwin, [:window_p, :int, :int, :int, :int], :window_p], [:doupdate, [], :int], [:dupwin, [:window_p], :window_p], [:echo, [], :int], [:echo_wchar, [:cchar_t_p], :int], [:echochar, [:chtype], :int], [:endwin, [], :int], [:erase, [], :int], [:erasechar, [], :char], [:erasewchar, [:wchar_t_p], :int], [:filter, [], :void], [:flash, [], :int], [:flushinp, [], :int], [:get_escdelay, [], :int], [:get_wch, [:wint_t_p], :int], [:get_wstr, [:wint_t_p], :int], [:getattrs, [:window_p], :int], [:getbegx, [:window_p], :int], [:getbegy, [:window_p], :int], [:getbkgd, [:window_p], :chtype], [:getbkgrnd, [:cchar_t_p], :int], [:getcchar, [:cchar_t_p, :wchar_t_p, :attr_t_p, :short_p, :pointer], :int], [:getch, [], :int], [:getcurx, [:window_p], :int], [:getcury, [:window_p], :int], [:getmaxx, [:window_p], :int], [:getmaxy, [:window_p], :int], [:getmouse, [:mevent_p], :int], [:getn_wstr, [:wint_t_p, :int], :int], [:getnstr, [:string, :int], :int], [:getparx, [:window_p], :int], [:getpary, [:window_p], :int], [:getstr, [:string], :int], [:getwin, [:file_p], :window_p], [:halfdelay, [:int], :int], [:has_colors, [], :bool], [:has_ic, [], :bool], [:has_il, [], :bool], [:has_key, [:int], :int], [:has_mouse, [], :bool], [:hide_panel, [:panel_p], :int], [:hline, [:chtype, :int], :int], [:hline_set, [:cchar_t_p, :int], :int], [:in_wch, [:cchar_t_p], :int], [:in_wchnstr, [:cchar_t_p, :int], :int], [:in_wchstr, [:cchar_t_p], :int], [:inch, [], :chtype], [:inchnstr, [:chtype_p, :int], :int], [:inchstr, [:chtype_p], :int], [:init_color, [:short, :short, :short, :short], :int], [:init_pair, [:short, :short, :short], :int], [:innstr, [:string, :int], :int], [:innwstr, [:wchar_t_p, :int], :int], [:ins_nwstr, [:wchar_t_p, :int], :int], [:ins_wch, [:cchar_t_p], :int], [:ins_wstr, [:wchar_t_p], :int], [:insch, [:chtype], :int], [:insdelln, [:int], :int], [:insertln, [], :int], [:insnstr, [:string, :int], :int], [:insstr, [:string], :int], [:instr, [:string], :int], [:inwstr, [:wchar_t_p], :int], [:is_cleared, [:window_p], :bool], [:is_idcok, [:window_p], :bool], [:is_idlok, [:window_p], :bool], [:is_immedok, [:window_p], :bool], [:is_keypad, [:window_p], :bool], [:is_leaveok, [:window_p], :bool], [:is_linetouched, [:window_p, :int], :bool], [:is_nodelay, [:window_p], :bool], [:is_notimeout, [:window_p], :bool], [:is_pad, [:window_p], :bool], [:is_scrollok, [:window_p], :bool], [:is_subwin, [:window_p], :bool], [:is_syncok, [:window_p], :bool], [:is_term_resized, [:int, :int], :bool], [:is_wintouched, [:window_p], :bool], [:isendwin, [], :bool], [:key_defined, [:string], :int], [:key_name, [:wchar_t], :string], [:keybound, [:int, :int], :string], [:keyname, [:int], :string], [:killchar, [], :char], [:killwchar, [:wchar_t_p], :int], [:longname, [], :string], [:mcprint, [:string, :int], :int], [:mouseinterval, [:int], :int], [:mousemask, [:mmask_t, :mmask_t_p], :mmask_t], [:move, [:int, :int], :int], [:move_panel, [:panel_p, :int, :int], :int], [:mvadd_wch, [:int, :int, :cchar_t_p], :int], [:mvadd_wchnstr, [:int, :int, :cchar_t_p, :int], :int], [:mvadd_wchstr, [:int, :int, :cchar_t_p], :int], [:mvaddch, [:int, :int, :chtype], :int], [:mvaddchnstr, [:int, :int, :chtype_p, :int], :int], [:mvaddchstr, [:int, :int, :chtype_p], :int], [:mvaddnstr, [:int, :int, :string, :int], :int], [:mvaddnwstr, [:int, :int, :wchar_t_p, :int], :int], [:mvaddstr, [:int, :int, :string], :int], [:mvaddwstr, [:int, :int, :wchar_t_p], :int], [:mvchgat, [:int, :int, :int, :attr_t, :short, :pointer], :int], [:mvcur, [:int, :int, :int, :int], :int], [:mvdelch, [:int, :int], :int], [:mvderwin, [:window_p, :int, :int], :int], [:mvget_wch, [:int, :int, :wint_t_p], :int], [:mvget_wstr, [:int, :int, :wint_t_p], :int], [:mvgetch, [:int, :int], :int], [:mvgetn_wstr, [:int, :int, :wint_t_p, :int], :int], [:mvgetnstr, [:int, :int, :string, :int], :int], [:mvgetstr, [:int, :int, :string], :int], [:mvhline, [:int, :int, :chtype, :int], :int], [:mvhline_set, [:int, :int, :cchar_t_p, :int], :int], [:mvin_wch, [:int, :int, :cchar_t_p], :int], [:mvin_wchnstr, [:int, :int, :cchar_t_p, :int], :int], [:mvin_wchstr, [:int, :int, :cchar_t_p], :int], [:mvinch, [:int, :int], :chtype], [:mvinchnstr, [:int, :int, :chtype_p, :int], :int], [:mvinchstr, [:int, :int, :chtype_p], :int], [:mvinnstr, [:int, :int, :string, :int], :int], [:mvinnwstr, [:int, :int, :wchar_t_p, :int], :int], [:mvins_nwstr, [:int, :int, :wchar_t_p, :int], :int], [:mvins_wch, [:int, :int, :cchar_t_p], :int], [:mvins_wstr, [:int, :int, :wchar_t_p], :int], [:mvinsch, [:int, :int, :chtype], :int], [:mvinsnstr, [:int, :int, :string, :int], :int], [:mvinsstr, [:int, :int, :string], :int], [:mvinstr, [:int, :int, :string], :int], [:mvinwstr, [:int, :int, :wchar_t_p], :int], [:mvprintw, [:int, :int, :string, :varargs], :int], [:mvscanw, [:int, :int, :string, :varargs], :int], [:mvvline, [:int, :int, :chtype, :int], :int], [:mvvline_set, [:int, :int, :cchar_t_p, :int], :int], [:mvwadd_wch, [:window_p, :int, :int, :cchar_t_p], :int], [:mvwadd_wchnstr, [:window_p, :int, :int, :cchar_t_p, :int], :int], [:mvwadd_wchstr, [:window_p, :int, :int, :cchar_t_p], :int], [:mvwaddch, [:window_p, :int, :int, :chtype], :int], [:mvwaddchnstr, [:window_p, :int, :int, :chtype_p, :int], :int], [:mvwaddchstr, [:window_p, :int, :int, :chtype_p], :int], [:mvwaddnstr, [:window_p, :int, :int, :string, :int], :int], [:mvwaddnwstr, [:window_p, :int, :int, :wchar_t_p, :int], :int], [:mvwaddstr, [:window_p, :int, :int, :string], :int], [:mvwaddwstr, [:window_p, :int, :int, :wchar_t_p], :int], [:mvwchgat, [:window_p, :int, :int, :int, :attr_t, :short, :pointer], :int], [:mvwdelch, [:window_p, :int, :int], :int], [:mvwget_wch, [:window_p, :int, :int, :wint_t_p], :int], [:mvwget_wstr, [:window_p, :int, :int, :wint_t_p], :int], [:mvwgetch, [:window_p, :int, :int], :int], [:mvwgetn_wstr, [:window_p, :int, :int, :wint_t_p, :int], :int], [:mvwgetnstr, [:window_p, :int, :int, :string, :int], :int], [:mvwgetstr, [:window_p, :int, :int, :string], :int], [:mvwhline, [:window_p, :int, :int, :chtype, :int], :int], [:mvwhline_set, [:window_p, :int, :int, :cchar_t_p, :int], :int], [:mvwin, [:window_p, :int, :int], :int], [:mvwin_wch, [:window_p, :int, :int, :cchar_t_p], :int], [:mvwin_wchnstr, [:window_p, :int, :int, :cchar_t_p, :int], :int], [:mvwin_wchstr, [:window_p, :int, :int, :cchar_t_p], :int], [:mvwinch, [:window_p, :int, :int], :chtype], [:mvwinchnstr, [:window_p, :int, :int, :chtype_p, :int], :int], [:mvwinchstr, [:window_p, :int, :int, :chtype_p], :int], [:mvwinnstr, [:window_p, :int, :int, :string, :int], :int], [:mvwinnwstr, [:window_p, :int, :int, :wchar_t_p, :int], :int], [:mvwins_nwstr, [:window_p, :int, :int, :wchar_t_p, :int], :int], [:mvwins_wch, [:window_p, :int, :int, :cchar_t_p], :int], [:mvwins_wstr, [:window_p, :int, :int, :wchar_t_p], :int], [:mvwinsch, [:window_p, :int, :int, :chtype], :int], [:mvwinsnstr, [:window_p, :int, :int, :string, :int], :int], [:mvwinsstr, [:window_p, :int, :int, :string], :int], [:mvwinstr, [:window_p, :int, :int, :string], :int], [:mvwinwstr, [:window_p, :int, :int, :wchar_t_p], :int], [:mvwprintw, [:window_p, :int, :int, :string, :varargs], :int], [:mvwscanw, [:window_p, :int, :int, :string, :varargs], :int], [:mvwvline, [:window_p, :int, :int, :chtype, :int], :int], [:mvwvline_set, [:window_p, :int, :int, :cchar_t_p, :int], :int], [:napms, [:int], :int], [:new_panel, [:window_p], :panel_p], [:newpad, [:int, :int], :window_p], [:newwin, [:int, :int, :int, :int], :window_p], [:nl, [], :int], [:nocbreak, [], :int], [:noecho, [], :int], [:nofilter, [], :void], [:nonl, [], :int], [:noqiflush, [], :void], [:noraw, [], :int], [:overlay, [:window_p, :window_p], :int], [:overwrite, [:window_p, :window_p], :int], [:pair_content, [:short, :short_p, :short_p], :int], [:panel_above, [:panel_p], :panel_p], [:panel_below, [:panel_p], :panel_p], [:panel_hidden, [:panel_p], :int], [:panel_userptr, [:panel_p], :pointer], [:panel_window, [:panel_p], :window_p], [:pecho_wchar, [:window_p, :cchar_t_p], :int], [:pechochar, [:window_p, :chtype], :int], [:pnoutrefresh, [:window_p, :int, :int, :int, :int, :int, :int], :int], [:prefresh, [:window_p, :int, :int, :int, :int, :int, :int], :int], [:printw, [:string, :varargs], :int], [:putp, [:string], :int], [:putwin, [:window_p, :file_p], :int], [:qiflush, [], :void], [:raw, [], :int], [:redrawwin, [:window_p], :int], [:refresh, [], :int], [:replace_panel, [:panel_p, :window_p], :int], [:reset_prog_mode, [], :int], [:reset_shell_mode, [], :int], [:resetty, [], :int], [:resize_term, [:int, :int], :int], [:resizeterm, [:int, :int], :int], [:ripoffline, [:int, :int_p], :int], [:savetty, [], :int], [:scanw, [:string, :varargs], :int], [:scr_dump, [:string], :int], [:scr_init, [:string], :int], [:scr_restore, [:string], :int], [:scr_set, [:string], :int], [:scrl, [:int], :int], [:scroll, [:window_p], :int], [:set_escdelay, [:int], :int], [:set_panel_userptr, [:panel_p, :pointer], :int], [:set_tabsize, [:int], :int], [:set_term, [:screen_p], :screen_p], [:setcchar, [:cchar_t_p, :wchar_t_p, :attr_t, :short, :pointer], :int], [:setscrreg, [:int, :int], :int], [:show_panel, [:panel_p], :int], [:slk_attr, [], :attr_t], [:slk_attr_off, [:attr_t, :pointer], :int], [:slk_attr_on, [:attr_t, :pointer], :int], [:slk_attr_set, [:attr_t, :short, :pointer], :int], [:slk_attroff, [:chtype], :int], [:slk_attron, [:chtype], :int], [:slk_attrset, [:chtype], :int], [:slk_clear, [], :int], [:slk_color, [:short], :int], [:slk_init, [:int], :int], [:slk_label, [:int], :string], [:slk_noutrefresh, [], :int], [:slk_refresh, [], :int], [:slk_restore, [], :int], [:slk_set, [:int, :string, :int], :int], [:slk_touch, [], :int], [:slk_wset, [:int, :wchar_t_p, :int], :int], [:standend, [], :int], [:standout, [], :int], [:start_color, [], :int], [:subpad, [:window_p, :int, :int, :int, :int], :window_p], [:subwin, [:window_p, :int, :int, :int, :int], :window_p], [:term_attrs, [], :attr_t], [:termattrs, [], :chtype], [:termname, [], :string], [:tigetflag, [:string], :int], [:tigetnum, [:string], :int], [:tigetstr, [:string], :string], [:timeout, [:int], :void], [:tiparm, [:string, :varargs], :string], [:top_panel, [:panel_p], :int], [:touchline, [:window_p, :int, :int], :int], [:touchwin, [:window_p], :int], [:tparm, [:string, :varargs], :string], [:trace, [:uint], :void], [:typeahead, [:int], :int], [:unctrl, [:chtype], :string], [:unget_wch, [:wchar_t], :int], [:ungetch, [:int], :int], [:ungetmouse, [:mevent_p], :int], [:untouchwin, [:window_p], :int], [:update_panels, [], :void], [:use_default_colors, [], :int], [:use_legacy_coding, [:int], :int], [:use_screen, [:screen_p, :pointer, :pointer], :int], [:use_window, [:window_p, :pointer, :pointer], :int], [:vid_attr, [:attr_t, :short, :pointer], :int], [:vid_puts, [:attr_t, :short, :pointer, :pointer], :int], [:vidattr, [:chtype], :int], [:vidputs, [:chtype, :pointer], :int], [:vline, [:chtype, :int], :int], [:vline_set, [:cchar_t_p, :int], :int], [:wadd_wch, [:window_p, :cchar_t_p], :int], [:wadd_wchnstr, [:window_p, :cchar_t_p, :int], :int], [:wadd_wchstr, [:window_p, :cchar_t_p], :int], [:waddch, [:window_p, :chtype], :int], [:waddchnstr, [:window_p, :chtype_p, :int], :int], [:waddchstr, [:window_p, :chtype_p], :int], [:waddnstr, [:window_p, :string, :int], :int], [:waddnwstr, [:window_p, :wchar_t_p, :int], :int], [:waddstr, [:window_p, :string], :int], [:waddwstr, [:window_p, :wchar_t_p], :int], [:wattr_get, [:window_p, :attr_t_p, :short_p, :pointer], :int], [:wattr_off, [:window_p, :attr_t, :pointer], :int], [:wattr_on, [:window_p, :attr_t, :pointer], :int], [:wattr_set, [:window_p, :attr_t, :short, :pointer], :int], [:wattroff, [:window_p, :int], :int], [:wattron, [:window_p, :int], :int], [:wattrset, [:window_p, :int], :int], [:wbkgd, [:window_p, :chtype], :int], [:wbkgdset, [:window_p, :chtype], :void], [:wbkgrnd, [:window_p, :cchar_t_p], :int], [:wbkgrndset, [:window_p, :cchar_t_p], :void], [:wborder, [:window_p, :chtype, :chtype, :chtype, :chtype, :chtype, :chtype, :chtype, :chtype], :int], [:wborder_set, [:window_p, :cchar_t_p, :cchar_t_p, :cchar_t_p, :cchar_t_p, :cchar_t_p, :cchar_t_p, :cchar_t_p, :cchar_t_p], :int], [:wchgat, [:window_p, :int, :attr_t, :short, :pointer], :int], [:wclear, [:window_p], :int], [:wclrtobot, [:window_p], :int], [:wclrtoeol, [:window_p], :int], [:wcolor_set, [:window_p, :short, :pointer], :int], [:wcursyncup, [:window_p], :void], [:wdelch, [:window_p], :int], [:wdeleteln, [:window_p], :int], [:wecho_wchar, [:window_p, :cchar_t_p], :int], [:wechochar, [:window_p, :chtype], :int], [:wenclose, [:window_p, :int, :int], :bool], [:werase, [:window_p], :int], [:wget_wch, [:window_p, :wint_t_p], :int], [:wget_wstr, [:window_p, :wint_t_p], :int], [:wgetbkgrnd, [:window_p, :cchar_t_p], :int], [:wgetch, [:window_p], :int], [:wgetn_wstr, [:window_p, :wint_t_p, :int], :int], [:wgetnstr, [:window_p, :string, :int], :int], [:wgetparent, [:window_p], :window_p], [:wgetscrreg, [:window_p, :int_p, :int_p], :int], [:wgetstr, [:window_p, :string], :int], [:whline, [:window_p, :chtype, :int], :int], [:whline_set, [:window_p, :cchar_t_p, :int], :int], [:win_wch, [:window_p, :cchar_t_p], :int], [:win_wchnstr, [:window_p, :cchar_t_p, :int], :int], [:win_wchstr, [:window_p, :cchar_t_p], :int], [:winch, [:window_p], :chtype], [:winchnstr, [:window_p, :chtype_p, :int], :int], [:winchstr, [:window_p, :chtype_p], :int], [:winnstr, [:window_p, :string, :int], :int], [:winnwstr, [:window_p, :wchar_t_p, :int], :int], [:wins_nwstr, [:window_p, :wchar_t_p, :int], :int], [:wins_wch, [:window_p, :cchar_t_p], :int], [:wins_wstr, [:window_p, :wchar_t_p], :int], [:winsch, [:window_p, :chtype], :int], [:winsdelln, [:window_p, :int], :int], [:winsertln, [:window_p], :int], [:winsnstr, [:window_p, :string, :int], :int], [:winsstr, [:window_p, :string], :int], [:winstr, [:window_p, :string], :int], [:winwstr, [:window_p, :wchar_t_p], :int], [:wmove, [:window_p, :int, :int], :int], [:wnoutrefresh, [:window_p], :int], [:wprintw, [:window_p, :string, :varargs], :int], [:wredrawln, [:window_p, :int, :int], :int], [:wrefresh, [:window_p], :int], [:wresize, [:window_p, :int, :int], :int], [:wscanw, [:window_p, :string, :varargs], :int], [:wscrl, [:window_p, :int], :int], [:wsetscrreg, [:window_p, :int, :int], :int], [:wstandend, [:window_p], :int], [:wstandout, [:window_p], :int], [:wsyncdown, [:window_p], :void], [:wsyncup, [:window_p], :void], [:wtimeout, [:window_p, :int], :void], [:wtouchln, [:window_p, :int, :int, :int], :int], [:wunctrl, [:cchar_t_p], :wchar_t_p], [:wvline, [:window_p, :chtype, :int], :int], [:wvline_set, [:window_p, :cchar_t_p, :int], :int], ]
Constants included from KeyDefs
KeyDefs::KEY_A1, KeyDefs::KEY_A3, KeyDefs::KEY_B2, KeyDefs::KEY_BACKSPACE, KeyDefs::KEY_BEG, KeyDefs::KEY_BREAK, KeyDefs::KEY_BTAB, KeyDefs::KEY_C1, KeyDefs::KEY_C3, KeyDefs::KEY_CANCEL, KeyDefs::KEY_CATAB, KeyDefs::KEY_CLEAR, KeyDefs::KEY_CLOSE, KeyDefs::KEY_CODE_YES, KeyDefs::KEY_COMMAND, KeyDefs::KEY_COPY, KeyDefs::KEY_CREATE, KeyDefs::KEY_CTAB, KeyDefs::KEY_DC, KeyDefs::KEY_DL, KeyDefs::KEY_DOWN, KeyDefs::KEY_EIC, KeyDefs::KEY_END, KeyDefs::KEY_ENTER, KeyDefs::KEY_EOL, KeyDefs::KEY_EOS, KeyDefs::KEY_ESCAPE, KeyDefs::KEY_EVENT, KeyDefs::KEY_EXIT, KeyDefs::KEY_F0, KeyDefs::KEY_FIND, KeyDefs::KEY_HELP, KeyDefs::KEY_HOME, KeyDefs::KEY_IC, KeyDefs::KEY_IL, KeyDefs::KEY_LEFT, KeyDefs::KEY_LL, KeyDefs::KEY_MARK, KeyDefs::KEY_MAX, KeyDefs::KEY_MESSAGE, KeyDefs::KEY_MIN, KeyDefs::KEY_MOUSE, KeyDefs::KEY_MOVE, KeyDefs::KEY_NEXT, KeyDefs::KEY_NPAGE, KeyDefs::KEY_OPEN, KeyDefs::KEY_OPTIONS, KeyDefs::KEY_PPAGE, KeyDefs::KEY_PREVIOUS, KeyDefs::KEY_PRINT, KeyDefs::KEY_REDO, KeyDefs::KEY_REFERENCE, KeyDefs::KEY_REFRESH, KeyDefs::KEY_REPLACE, KeyDefs::KEY_RESET, KeyDefs::KEY_RESIZE, KeyDefs::KEY_RESTART, KeyDefs::KEY_RESUME, KeyDefs::KEY_RETURN, KeyDefs::KEY_RIGHT, KeyDefs::KEY_SAVE, KeyDefs::KEY_SBEG, KeyDefs::KEY_SCANCEL, KeyDefs::KEY_SCOMMAND, KeyDefs::KEY_SCOPY, KeyDefs::KEY_SCREATE, KeyDefs::KEY_SDC, KeyDefs::KEY_SDL, KeyDefs::KEY_SELECT, KeyDefs::KEY_SEND, KeyDefs::KEY_SEOL, KeyDefs::KEY_SEXIT, KeyDefs::KEY_SF, KeyDefs::KEY_SFIND, KeyDefs::KEY_SHELP, KeyDefs::KEY_SHOME, KeyDefs::KEY_SIC, KeyDefs::KEY_SLEFT, KeyDefs::KEY_SMESSAGE, KeyDefs::KEY_SMOVE, KeyDefs::KEY_SNEXT, KeyDefs::KEY_SOPTIONS, KeyDefs::KEY_SPREVIOUS, KeyDefs::KEY_SPRINT, KeyDefs::KEY_SR, KeyDefs::KEY_SREDO, KeyDefs::KEY_SREPLACE, KeyDefs::KEY_SRESET, KeyDefs::KEY_SRIGHT, KeyDefs::KEY_SRSUME, KeyDefs::KEY_SSAVE, KeyDefs::KEY_SSUSPEND, KeyDefs::KEY_STAB, KeyDefs::KEY_SUNDO, KeyDefs::KEY_SUSPEND, KeyDefs::KEY_TAB, KeyDefs::KEY_UNDO, KeyDefs::KEY_UP
Constants included from Mouse
Mouse::ALL_MOUSE_EVENTS, Mouse::BUTTON1_CLICKED, Mouse::BUTTON1_DOUBLE_CLICKED, Mouse::BUTTON1_PRESSED, Mouse::BUTTON1_RELEASED, Mouse::BUTTON1_RESERVED_EVENT, Mouse::BUTTON1_TRIPLE_CLICKED, Mouse::BUTTON2_CLICKED, Mouse::BUTTON2_DOUBLE_CLICKED, Mouse::BUTTON2_PRESSED, Mouse::BUTTON2_RELEASED, Mouse::BUTTON2_RESERVED_EVENT, Mouse::BUTTON2_TRIPLE_CLICKED, Mouse::BUTTON3_CLICKED, Mouse::BUTTON3_DOUBLE_CLICKED, Mouse::BUTTON3_PRESSED, Mouse::BUTTON3_RELEASED, Mouse::BUTTON3_RESERVED_EVENT, Mouse::BUTTON3_TRIPLE_CLICKED, Mouse::BUTTON4_CLICKED, Mouse::BUTTON4_DOUBLE_CLICKED, Mouse::BUTTON4_PRESSED, Mouse::BUTTON4_RELEASED, Mouse::BUTTON4_RESERVED_EVENT, Mouse::BUTTON4_TRIPLE_CLICKED, Mouse::BUTTON5_CLICKED, Mouse::BUTTON5_DOUBLE_CLICKED, Mouse::BUTTON5_PRESSED, Mouse::BUTTON5_RELEASED, Mouse::BUTTON5_TRIPLE_CLICKED, Mouse::BUTTON_ALT, Mouse::BUTTON_CTRL, Mouse::BUTTON_SHIFT, Mouse::NCURSES_BUTTON_CLICKED, Mouse::NCURSES_BUTTON_PRESSED, Mouse::NCURSES_BUTTON_RELEASED, Mouse::NCURSES_DOUBLE_CLICKED, Mouse::NCURSES_MOUSE_VERSION, Mouse::NCURSES_RESERVED_EVENT, Mouse::NCURSES_TRIPLE_CLICKED, Mouse::REPORT_MOUSE_POSITION
Constants included from WinStruct
WinStruct::BOOLEAN, WinStruct::CCHARW_MAX, WinStruct::CHTYPE, WinStruct::NCURSES_ATTR_T, WinStruct::NCURSES_CH_T, WinStruct::NCURSES_COLOR_T, WinStruct::NCURSES_SIZE_T, WinStruct::WCHAR_T
Constants included from Constants
Constants included from Attributes
Attributes::NCURSES_ATTR_SHIFT, Attributes::WA_ALTCHARSET, Attributes::WA_ATTRIBUTES, Attributes::WA_BLINK, Attributes::WA_BOLD, Attributes::WA_CHARTEXT, Attributes::WA_COLOR, Attributes::WA_DIM, Attributes::WA_HORIZONTAL, Attributes::WA_INVIS, Attributes::WA_LEFT, Attributes::WA_LOW, Attributes::WA_NORMAL, Attributes::WA_PROTECT, Attributes::WA_REVERSE, Attributes::WA_RIGHT, Attributes::WA_STANDOUT, Attributes::WA_TOP, Attributes::WA_UNDERLINE, Attributes::WA_VERTICAL
Constants included from Color
Color::COLOR_BLACK, Color::COLOR_BLUE, Color::COLOR_CYAN, Color::COLOR_GREEN, Color::COLOR_MAGENTA, Color::COLOR_RED, Color::COLOR_WHITE, Color::COLOR_YELLOW
Class Method Summary collapse
Instance Method Summary collapse
Methods included from EmulatedFunctions
fixup, getbegyx, getmaxyx, getparyx, getsyx, getyx, setsyx
Methods included from BoolWrappers
clearok, idcok, idlok, immedok, intrflush, keyok, keypad, leaveok, meta, mouse_trafo, nodelay, notimeout, scrollok, syncok, to_bool, use_env, use_extended_names, wmouse_trafo
Methods included from KeyDefs::KeyHelper
Methods included from Mouse
#BUTTON_CLICK, #BUTTON_DOUBLE_CLICK, #BUTTON_PRESS, #BUTTON_RELEASE, #BUTTON_RESERVED_EVENT, #BUTTON_TRIPLE_CLICK, NCURSES_MOUSE_MASK
Methods included from ACS
#define_acs, #define_acs_constants, #maybe_const_set
Methods included from Darwin
#getattrs, #getbegx, #getbegy, #getcurx, #getcury, #getmaxx, #getmaxy, #getparx, #getpary
Methods included from WinStruct
#is_cleared, #is_idcok, #is_idlok, #is_immedok, #is_keypad, #is_leaveok, #is_nodelay, #is_notimeout, #is_scrollok, #is_syncok, #wgetparent, #wgetscrreg
Methods included from Attributes
Class Method Details
.unattached_functions ⇒ Object
137 138 139 |
# File 'lib/ffi-ncurses.rb', line 137 def unattached_functions @unattached_functions end |
Instance Method Details
#initscr ⇒ Object
311 312 313 314 315 |
# File 'lib/ffi-ncurses.rb', line 311 def initscr _wrapped_initscr NCurses.define_acs_constants stdscr end |
#newterm(name, out_filep, in_filep) ⇒ Object
317 318 319 320 321 |
# File 'lib/ffi-ncurses.rb', line 317 def newterm(name, out_filep, in_filep) rv = _wrapped_newterm(name, out_filep, in_filep) NCurses.define_acs_constants rv end |